@@ -2,10 +2,9 @@ from __future__ import absolute_import
 
 import abc
 import typing
-from copy import deepcopy
 
 from applitools.common import AppOutput, RectangleSize, Region, RunningSession, logger
-from applitools.common.config import BatchInfo, Configuration
+from applitools.common.config import Configuration
 from applitools.common.errors import (
     DiffsFoundError,
     EyesError,
@@ -16,8 +15,9 @@ from applitools.common.match import MatchResult
 from applitools.common.metadata import AppEnvironment, SessionStartInfo
 from applitools.common.server import FailureReports, SessionType
 from applitools.common.test_results import TestResults
-from applitools.common.utils import ABC, argument_guard, general_utils
-from applitools.common.visual_grid import RenderingInfo
+from applitools.common.utils import ABC, argument_guard
+from applitools.common.utils.compat import raise_from
+from applitools.common.ultrafastgrid import RenderingInfo
 from applitools.core.capture import AppOutputProvider, AppOutputWithScreenshot
 from applitools.core.cut import (
     FixedCutProvider,
@@ -39,7 +39,8 @@ if typing.TYPE_CHECKING:
     from applitools.common.utils.custom_types import ViewPort, UserInputs, Num
     from applitools.core.fluent.check_settings import CheckSettings
     from applitools.common.capture import EyesScreenshot
-    from typing import Optional, Text, Union, Any
+    from applitools.common import MatchLevel
+    from typing import Optional, Text, Union
 
 __all__ = ("EyesBase",)
 
@@ -137,6 +138,16 @@ class EyesBase(EyesConfigurationMixin, _EyesBaseAbstract, ABC):
         self._user_inputs = []  # type: UserInputs
         self._debug_screenshot_provider = NullDebugScreenshotProvider()
 
+    @property
+    def match_level(self):
+        # type: () -> MatchLevel
+        return self.configure.match_level
+
+    @match_level.setter
+    def match_level(self, match_level):
+        # type: (MatchLevel) -> None
+        self.configure.match_level = match_level
+
     @property
     def is_cut_provider_explicitly_set(self):
         return self._cut_provider and not (
@@ -235,6 +246,7 @@ class EyesBase(EyesConfigurationMixin, _EyesBaseAbstract, ABC):
 
     @property
     def agent_setup(self):
+        # TODO: Implement agent_setup
         return None
 
     def add_property(self, name, value):
@@ -244,10 +256,13 @@ class EyesBase(EyesConfigurationMixin, _EyesBaseAbstract, ABC):
         :param name: (string) The property name.
         :param value: (string) The property value
         """
-        self.configure.properties.append({"name": name, "value": value})
+        self.configure.add_property(name, value)
 
     def clear_properties(self):
-        del self.configure.properties[:]
+        """
+        Clears the list of custom properties.
+        """
+        self.configure.clear_properties()
 
     @property
     def is_open(self):
@@ -314,7 +329,7 @@ class EyesBase(EyesConfigurationMixin, _EyesBaseAbstract, ABC):
             if not self._running_session:
                 logger.debug("close(): Server session was not started")
                 logger.info("close(): --- Empty test ended.")
-                return TestResults()
+                return TestResults(status="Failed")
 
             is_new_session = self._running_session.is_new_session
             results_url = self._running_session.url
@@ -323,7 +338,7 @@ class EyesBase(EyesConfigurationMixin, _EyesBaseAbstract, ABC):
             should_save = (is_new_session and self.configure.save_new_tests) or (
                 (not is_new_session) and self.configure.save_failed_tests
             )
-            logger.debug("close(): automatically save session? %s" % should_save)
+            logger.info("close(): Automatically save session? %s" % should_save)
             results = self._server_connector.stop_session(
                 self._running_session, False, should_save
             )
@@ -362,7 +377,6 @@ class EyesBase(EyesConfigurationMixin, _EyesBaseAbstract, ABC):
                     return results
                 except EyesError as e:
                     logger.info("Failed to abort server session: %s " % e)
-                    pass
                 finally:
                     self._running_session = None
         finally:
@@ -481,15 +495,15 @@ class EyesBase(EyesConfigurationMixin, _EyesBaseAbstract, ABC):
             raise EyesError("A test is already running")
 
     def _log_open_base(self):
-        logger.debug("Eyes server URL is '{}'".format(self.configure.server_url))
-        logger.debug("Timeout = {} ms".format(self.configure._timeout))
+        logger.info("Eyes server URL is '{}'".format(self.configure.server_url))
+        logger.info("Timeout = {} ms".format(self.configure._timeout))
         logger.debug("match_timeout = {} ms".format(self.configure.match_timeout))
-        logger.debug(
+        logger.info(
             "Default match settings = '{}' ".format(
                 self.configure.default_match_settings
             )
         )
-        logger.debug("FailureReports = '{}' ".format(self.configure.failure_reports))
+        logger.info("FailureReports = '{}' ".format(self.configure.failure_reports))
 
     def _create_session_start_info(self):
         # type: () -> None
@@ -520,7 +534,9 @@ class EyesBase(EyesConfigurationMixin, _EyesBaseAbstract, ABC):
         # initialization of Eyes parameters if empty from ENV variables
         logger.info("Batch is {}".format(self.configure.batch))
 
-        self._server_connector.update_config(self.get_configuration())
+        self._server_connector.update_config(
+            self.get_configuration(), self.full_agent_id
+        )
         self._create_session_start_info()
         # Actually start the session.
         self._running_session = self._server_connector.start_session(
@@ -552,7 +568,7 @@ class EyesBase(EyesConfigurationMixin, _EyesBaseAbstract, ABC):
 
     def _get_app_output_with_screenshot(self, region, last_screenshot, check_settings):
         # type: (Region, EyesScreenshot, CheckSettings) -> AppOutputWithScreenshot
-        logger.info("getting screenshot...")
+        logger.info("Getting screenshot...")
         screenshot = self._get_screenshot()
         logger.info("Done getting screenshot!")
         if not region.is_size_empty:
@@ -562,15 +578,16 @@ class EyesBase(EyesConfigurationMixin, _EyesBaseAbstract, ABC):
         if not self._dom_url and (
             self.configure.send_dom or check_settings.values.send_dom
         ):
+            logger.info("Capturing DOM")
             dom_json = self._try_capture_dom()
             self._dom_url = self._try_post_dom_capture(dom_json)
-            logger.info("dom_url: {}".format(self._dom_url))
+            logger.info("Captured DOM URL: {}".format(self._dom_url))
 
         app_output = AppOutput(
             title=self._title, screenshot_bytes=None, dom_url=self._dom_url
         )
         result = AppOutputWithScreenshot(app_output, screenshot)
-        logger.info("Done")
+        logger.info("Done getting screenshot and DOM!")
         return result
 
     def _before_match_window(self):
@@ -662,17 +679,17 @@ class EyesBase(EyesConfigurationMixin, _EyesBaseAbstract, ABC):
         """
         Assign the viewport size we need to be in the default content frame.
         """
-        if not self._is_viewport_size_set:
-            try:
-                if self.configure.viewport_size is None:
-                    # TODO: ignore if viewport_size settled explicitly
-                    target_size = self._get_viewport_size()
-                    self.configure.viewport_size = target_size
-                else:
-                    target_size = self.configure.viewport_size
-                    self._set_viewport_size(target_size)
-                self._is_viewport_size_set = True
-            except Exception as e:
-                logger.warning("Viewport has not been setup. {}".format(e))
-                self._is_viewport_size_set = False
-                raise e
+        if self._is_viewport_size_set:
+            return
+        try:
+            if self.configure.viewport_size is None:
+                # TODO: ignore if viewport_size settled explicitly
+                target_size = self._get_viewport_size()
+                self.configure.viewport_size = target_size
+            else:
+                target_size = self.configure.viewport_size
+                self._set_viewport_size(target_size)
+            self._is_viewport_size_set = True
+        except Exception as e:
+            self._is_viewport_size_set = False
+            raise_from(EyesError("Viewport has not been setup"), e)
